@@ -43,6 +43,7 @@ logger = logging.getLogger('sentry.errors')
 UNSAVED = dict()
 MAX_TAG_LENGTH = 200
 
+
 def get_checksum_from_event(event):
     for interface in event.interfaces.itervalues():
         result = interface.get_hash()
@@ -615,7 +616,7 @@ class GroupManager(BaseManager, ChartMixin):
         project = group.project
         date = group.last_seen
 
-        for key, value in itertools.ifilter(bool, tags):
+        for key, value in itertools.ifilter(lambda x: bool(x[1]), tags):
             if len(value) > MAX_TAG_LENGTH:
                 continue
 
